@@ -1,11 +1,12 @@
 use std::{
     error,
     fs::{remove_file, File, OpenOptions},
-    io,
-    net::SocketAddr,
-    time::Duration,
+    io::{self},
+    net::{SocketAddr, IpAddr, Ipv4Addr},
+    time::Duration, sync::Arc,
 };
-
+#[cfg(feature = "logging")]
+use log::debug;
 use tokio::{net::UdpSocket, time};
 
 use crate::{read_position, recv, send_unil_recv, u8s_to_u64, write_position};
@@ -294,14 +295,39 @@ fn write_msg(
 
 pub async fn recv_file(
     file: &mut File,
-    sock: &UdpSocket,
-    ip: SocketAddr,
+    local_port: u16,
+    sender: SocketAddr,
     progress_tracking: ProgressTracking,
 ) -> Result<(), Box<dyn error::Error>> {
+    let sock_addr = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(0, 0, 0, 0)), local_port);
+    let sock = UdpSocket::bind(sock_addr).await?;
+    let sock = Arc::new(sock);
+
+    let sock_ = sock.clone();
+    let holepuncher = tokio::task::spawn(async move {
+        let sock = sock_;
+
+        let mut holepunch_interval = time::interval(Duration::from_secs(5));
+        loop {
+            sock.send_to(&[255u8], sender).await.unwrap();
+
+            holepunch_interval.tick().await;
+        }
+    });
+
+    #[cfg(feature = "logging")]
+    debug!("getting file size");
+
+    // Recieve file size from sender
     let buf: [u8; 508];
     let amt = loop {
         let mut new_buf = [0u8; 508];
-        let amt = send_unil_recv(&sock, &[9], &ip, &mut new_buf, 500).await?;
+
+        // Send message to sender until a messge gets recieved
+        let amt = send_unil_recv(&*sock, &[9], &sender, &mut new_buf, 500).await?;
+
+        #[cfg(feature = "logging")]
+        debug!("got size msg: {:?}", &new_buf[0..amt]);
 
         if amt == 9 && new_buf[0] == 8 {
             buf = new_buf;
@@ -313,6 +339,8 @@ pub async fn recv_file(
     let size_be_bytes = &buf[1..];
     let size = u8s_to_u64(size_be_bytes)?;
 
+    #[cfg(feature = "logging")]
+    debug!("size: {}", size);
     // When the giver think it's done it should say that to the taker
     // the taker should check that it has recieved all packets
     // If not, the taker should send what messages are unsent
@@ -344,15 +372,12 @@ pub async fn recv_file(
                             break;
                         }
 
-                        amt = recv(&sock, &ip, &mut buf) => {
+                        amt = recv(&sock, &sender, &mut buf) => {
                             let amt = amt?;
                             let buf = &buf[0..amt];
 
                             if buf[0] == 5 {
-                                #[cfg(feature = "sim_wan")]
-                                send_maybe(&sock, &[7], &ip).await?;
-                                #[cfg(not(feature = "sim_wan"))]
-                                sock.send_to(&[7], ip).await?;
+                                sock.send_to(&[7], sender).await?;
 
                             }
 
@@ -366,7 +391,7 @@ pub async fn recv_file(
 
             let mut buf = [0u8; 508];
             loop {
-                let amt = send_unil_recv(&sock, &dropped_msg, &ip, &mut buf, 100).await?;
+                let amt = send_unil_recv(&sock, &dropped_msg, &sender, &mut buf, 100).await?;
                 let msg_buf = &buf[0..amt];
                 // If it's the same message
                 if msg_buf.len() != 1 && msg_buf[0] != 5 {
@@ -393,7 +418,7 @@ pub async fn recv_file(
                         break;
                     }
 
-                    amt = recv(&sock, &ip, &mut buf) => {
+                    amt = recv(&sock, &sender, &mut buf) => {
                         let amt = amt?;
                         amt
                     }
@@ -420,7 +445,7 @@ pub async fn recv_file(
             first = false;
         }
     }
-
+    holepuncher.abort();
     prog_tracker.destruct();
     Ok(())
 }
