@@ -1,9 +1,9 @@
-use std::{error, fs::File, net::SocketAddr, thread, time::Duration};
+use std::{error, fs::File, net::{SocketAddr, IpAddr, Ipv4Addr}, thread, time::Duration, sync::Arc};
 
+#[cfg(feature = "logging")]
+use log::{debug};
 use tokio::{net::UdpSocket, time};
 
-#[cfg(feature = "sim_wan")]
-use shared::send_maybe;
 
 use crate::{get_buf, punch_hole, read_position, send_unil_recv, u8s_to_u64};
 
@@ -22,15 +22,31 @@ fn get_file_buf_from_msg_num(
 const SEND_FILE_INTERVAL: u64 = 1500;
 
 pub async fn send_file(
-    sock: &UdpSocket,
+    local_port: u16,
     file_name: &str,
     reciever: SocketAddr,
 ) -> Result<(), Box<dyn error::Error>> {
+    #[cfg(feature = "logging")]
+    debug!("reciever ip: {}", reciever);
+
+    let sock_addr = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(0, 0, 0, 0)), local_port);
+    let sock = UdpSocket::bind(sock_addr).await?;
+    let sock = Arc::new(sock);
+
     // TODO: Send amount of bytes in file
     // TODO: Add function for sending until request stops
     // TODO: Make different ways to keep track of progress
+    let sock_ = sock.clone();
+    let holepuncher = tokio::task::spawn(async move {
+        let sock = sock_;
 
-    punch_hole(&sock, reciever).await?;
+        let mut holepunch_interval = time::interval(Duration::from_secs(5));
+        loop {
+            punch_hole(&sock, reciever).await.unwrap();
+
+            holepunch_interval.tick().await;
+        }
+    });
 
     thread::sleep(Duration::from_millis(1000));
 
@@ -50,6 +66,8 @@ pub async fn send_file(
         file_len_arr[7],
     ];
 
+    #[cfg(feature = "logging")]
+    debug!("sending file size...");
     let mut has_sent = false;
     loop {
         let mut buf = [0u8; 508];
@@ -65,6 +83,9 @@ pub async fn send_file(
                 let amt = amt?;
                 let buf = &buf[0..amt];
 
+                #[cfg(feature = "logging")]
+                debug!("got msg: {:?}", buf);
+
                 if buf.len() == 1 && buf[0] == 9 {
                     sock.send_to(&msg, reciever).await?;
                     has_sent = true;
@@ -73,6 +94,8 @@ pub async fn send_file(
 
         }
     }
+    #[cfg(feature = "logging")]
+    debug!("has sent file size");
 
     // Udp messages should be 508 bytes
     // 8 of those bytes are used for checking order of recieving bytes
@@ -90,9 +113,6 @@ pub async fn send_file(
 
         send_interval.tick().await;
 
-        #[cfg(feature = "sim_wan")]
-        send_maybe(&sock, &buf, &reciever).await?;
-        #[cfg(not(feature = "sim_wan"))]
         sock.send_to(&buf, reciever).await?;
 
         offset += 500;
@@ -103,15 +123,19 @@ pub async fn send_file(
         msg_num += 1;
     }
 
+    #[cfg(feature = "logging")]
+    debug!("first pass of sending done");
+
     loop {
         let mut buf = [0u8; 508];
-        let amt = send_unil_recv(&sock, &[5], &reciever, &mut buf, 10).await?;
+        let amt = send_unil_recv(&sock, &[5], &reciever, &mut buf, 100).await?;
 
         // This will be an array of u64s with missed things
         // The first will be a message
         let buf = &buf[0..amt];
         if buf[0] == 7 {
             // 6 is missed
+            holepuncher.abort();
             return Ok(());
         }
 
@@ -127,10 +151,8 @@ pub async fn send_file(
             let buf = get_buf(&missed_msg, file_buf);
 
             send_interval.tick().await;
-            #[cfg(feature = "sim_wan")]
-            send_maybe(&sock, &buf, &reciever).await?;
-            #[cfg(not(feature = "sim_wan"))]
             sock.send_to(&buf, reciever).await?;
         }
     }
+
 }
